from abc import ABC, abstractmethod
from typing import List

from workspaces.capability.schema_interfaces import CapabilityRequestIF
from workspaces.notification.schema import NotificationTemplate, Base


class NotificationInfoIF(ABC):
    """
    Data access object that can look up notification templates etc.
    """

    def all_templates(self) -> List[NotificationTemplate]:
        raise NotImplementedError

    def lookup_template(self, template_name: str) -> NotificationTemplate:
        raise NotImplementedError

    def create_template(self, template_name: str, description: str, template: str) -> NotificationTemplate:
        raise NotImplementedError

    def delete_template(self, template_name: str):
        raise NotImplementedError

    def save_entity(self, entity: Base):
        pass


class NotificationServiceIF(ABC):
    """
    The notification service: clients access this to send user notification emails
    """

    def notify_submitted(self, request: CapabilityRequestIF):
        raise NotImplementedError

    def notify_complete(self, request: CapabilityRequestIF):
        raise NotImplementedError

    def notify_failed(self, request: CapabilityRequestIF):
        raise NotImplementedError
